<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="pt">
<context>
    <name>Application</name>
    <message>
        <location filename="../reader/Application.cpp" line="39"/>
        <source>Document Viewer</source>
        <translation>Visualizador de Documentos</translation>
    </message>
    <message>
        <location filename="../reader/Application.cpp" line="40"/>
        <source>Document Viewer is a tool for reading document files, supporting PDF, DJVU, DOCX etc.</source>
        <translation>O Visualizador de Documentos é uma ferramenta de leitura de ficheiros de documentos, suportando PDF, DJVU, DOCX, etc.</translation>
    </message>
</context>
<context>
    <name>AttrScrollWidget</name>
    <message>
        <location filename="../reader/widgets/AttrScrollWidget.cpp" line="46"/>
        <source>Location</source>
        <translation>Localização</translation>
    </message>
    <message>
        <location filename="../reader/widgets/AttrScrollWidget.cpp" line="47"/>
        <source>Subject</source>
        <translation>Assunto</translation>
    </message>
    <message>
        <location filename="../reader/widgets/AttrScrollWidget.cpp" line="48"/>
        <source>Author</source>
        <translation>Autor</translation>
    </message>
    <message>
        <location filename="../reader/widgets/AttrScrollWidget.cpp" line="49"/>
        <source>Keywords</source>
        <translation>Palavras-chave</translation>
    </message>
    <message>
        <location filename="../reader/widgets/AttrScrollWidget.cpp" line="50"/>
        <source>Producer</source>
        <translation>Produtor</translation>
    </message>
    <message>
        <location filename="../reader/widgets/AttrScrollWidget.cpp" line="51"/>
        <source>Creator</source>
        <translation>Criador</translation>
    </message>
    <message>
        <location filename="../reader/widgets/AttrScrollWidget.cpp" line="52"/>
        <source>Time created</source>
        <translation>Data de criação</translation>
    </message>
    <message>
        <location filename="../reader/widgets/AttrScrollWidget.cpp" line="53"/>
        <source>Time modified</source>
        <translation>Data de modificação</translation>
    </message>
    <message>
        <location filename="../reader/widgets/AttrScrollWidget.cpp" line="54"/>
        <source>Format</source>
        <translation>Formato</translation>
    </message>
    <message>
        <location filename="../reader/widgets/AttrScrollWidget.cpp" line="55"/>
        <source>Pages</source>
        <translation>Páginas</translation>
    </message>
    <message>
        <location filename="../reader/widgets/AttrScrollWidget.cpp" line="56"/>
        <source>Optimized</source>
        <translation>Optimizado</translation>
    </message>
    <message>
        <location filename="../reader/widgets/AttrScrollWidget.cpp" line="57"/>
        <source>Security</source>
        <translation>Segurança</translation>
    </message>
    <message>
        <location filename="../reader/widgets/AttrScrollWidget.cpp" line="59"/>
        <source>Page size</source>
        <translation>Tamanho da página</translation>
    </message>
    <message>
        <location filename="../reader/widgets/AttrScrollWidget.cpp" line="60"/>
        <source>File size</source>
        <translation>Tamanho do ficheiro</translation>
    </message>
    <message>
        <location filename="../reader/widgets/AttrScrollWidget.cpp" line="65"/>
        <source>Basic info</source>
        <translation>Informação básica</translation>
    </message>
    <message>
        <location filename="../reader/widgets/AttrScrollWidget.cpp" line="85"/>
        <source>Unknown</source>
        <translation>Desconhecido</translation>
    </message>
    <message>
        <location filename="../reader/widgets/AttrScrollWidget.cpp" line="127"/>
        <source>Yes</source>
        <translation>Sim</translation>
    </message>
    <message>
        <location filename="../reader/widgets/AttrScrollWidget.cpp" line="127"/>
        <source>No</source>
        <translation>Não</translation>
    </message>
</context>
<context>
    <name>BookMarkWidget</name>
    <message>
        <location filename="../reader/sidebar/BookMarkWidget.cpp" line="64"/>
        <source>Add bookmark</source>
        <translation>Adicionar marcador</translation>
    </message>
    <message>
        <location filename="../reader/sidebar/BookMarkWidget.cpp" line="220"/>
        <source>Are you sure you want to delete all bookmarks?</source>
        <translation>Tem a certeza que deseja eliminar todos os marcadores?</translation>
    </message>
</context>
<context>
    <name>BrowserMenu</name>
    <message>
        <location filename="../reader/browser/BrowserMenu.cpp" line="39"/>
        <location filename="../reader/browser/BrowserMenu.cpp" line="52"/>
        <location filename="../reader/browser/BrowserMenu.cpp" line="56"/>
        <source>Copy</source>
        <translation>Copiar</translation>
    </message>
    <message>
        <location filename="../reader/browser/BrowserMenu.cpp" line="43"/>
        <source>Remove annotation</source>
        <translation>Remover anotação</translation>
    </message>
    <message>
        <location filename="../reader/browser/BrowserMenu.cpp" line="44"/>
        <location filename="../reader/browser/BrowserMenu.cpp" line="73"/>
        <location filename="../reader/browser/BrowserMenu.cpp" line="134"/>
        <source>Add annotation</source>
        <translation>Adicionar anotação</translation>
    </message>
    <message>
        <location filename="../reader/browser/BrowserMenu.cpp" line="47"/>
        <location filename="../reader/browser/BrowserMenu.cpp" line="77"/>
        <location filename="../reader/browser/BrowserMenu.cpp" line="85"/>
        <location filename="../reader/browser/BrowserMenu.cpp" line="129"/>
        <source>Remove bookmark</source>
        <translation>Remover marcador</translation>
    </message>
    <message>
        <location filename="../reader/browser/BrowserMenu.cpp" line="49"/>
        <location filename="../reader/browser/BrowserMenu.cpp" line="79"/>
        <location filename="../reader/browser/BrowserMenu.cpp" line="87"/>
        <location filename="../reader/browser/BrowserMenu.cpp" line="131"/>
        <source>Add bookmark</source>
        <translation>Adicionar marcador</translation>
    </message>
    <message>
        <location filename="../reader/browser/BrowserMenu.cpp" line="60"/>
        <source>Highlight</source>
        <translation>Destacar</translation>
    </message>
    <message>
        <location filename="../reader/browser/BrowserMenu.cpp" line="69"/>
        <source>Remove highlight</source>
        <translation>Remover destaque</translation>
    </message>
    <message>
        <location filename="../reader/browser/BrowserMenu.cpp" line="81"/>
        <location filename="../reader/browser/BrowserMenu.cpp" line="124"/>
        <source>Search</source>
        <translation>Pesquisar</translation>
    </message>
    <message>
        <location filename="../reader/browser/BrowserMenu.cpp" line="92"/>
        <location filename="../reader/browser/BrowserMenu.cpp" line="140"/>
        <source>Exit fullscreen</source>
        <translation>Sair de ecrã inteiro</translation>
    </message>
    <message>
        <location filename="../reader/browser/BrowserMenu.cpp" line="94"/>
        <location filename="../reader/browser/BrowserMenu.cpp" line="142"/>
        <source>Fullscreen</source>
        <translation>Ecrã inteiro</translation>
    </message>
    <message>
        <location filename="../reader/browser/BrowserMenu.cpp" line="97"/>
        <location filename="../reader/browser/BrowserMenu.cpp" line="145"/>
        <source>Slide show</source>
        <translation>Apresentação</translation>
    </message>
    <message>
        <location filename="../reader/browser/BrowserMenu.cpp" line="100"/>
        <location filename="../reader/browser/BrowserMenu.cpp" line="148"/>
        <source>First page</source>
        <translation>Primeira página</translation>
    </message>
    <message>
        <location filename="../reader/browser/BrowserMenu.cpp" line="101"/>
        <location filename="../reader/browser/BrowserMenu.cpp" line="149"/>
        <source>Previous page</source>
        <translation>Página anterior</translation>
    </message>
    <message>
        <location filename="../reader/browser/BrowserMenu.cpp" line="107"/>
        <location filename="../reader/browser/BrowserMenu.cpp" line="155"/>
        <source>Next page</source>
        <translation>Página seguinte</translation>
    </message>
    <message>
        <location filename="../reader/browser/BrowserMenu.cpp" line="108"/>
        <location filename="../reader/browser/BrowserMenu.cpp" line="156"/>
        <source>Last page</source>
        <translation>Última página</translation>
    </message>
    <message>
        <location filename="../reader/browser/BrowserMenu.cpp" line="116"/>
        <location filename="../reader/browser/BrowserMenu.cpp" line="164"/>
        <source>Rotate left</source>
        <translation>Rodar para a esquerda</translation>
    </message>
    <message>
        <location filename="../reader/browser/BrowserMenu.cpp" line="117"/>
        <location filename="../reader/browser/BrowserMenu.cpp" line="165"/>
        <source>Rotate right</source>
        <translation>Rodar para a direita</translation>
    </message>
    <message>
        <location filename="../reader/browser/BrowserMenu.cpp" line="120"/>
        <location filename="../reader/browser/BrowserMenu.cpp" line="168"/>
        <source>Print</source>
        <translation>Imprimir</translation>
    </message>
    <message>
        <location filename="../reader/browser/BrowserMenu.cpp" line="121"/>
        <location filename="../reader/browser/BrowserMenu.cpp" line="169"/>
        <source>Document info</source>
        <translation>Informações do documento</translation>
    </message>
</context>
<context>
    <name>Central</name>
    <message>
        <location filename="../reader/uiframe/Central.cpp" line="147"/>
        <source>Documents</source>
        <translation>Documentos</translation>
    </message>
</context>
<context>
    <name>CentralDocPage</name>
    <message>
        <location filename="../reader/uiframe/CentralDocPage.cpp" line="166"/>
        <source>The format is not supported</source>
        <translation>O formato não é suportado</translation>
    </message>
    <message>
        <location filename="../reader/uiframe/CentralDocPage.cpp" line="208"/>
        <source>Open failed</source>
        <translation>Falha ao abrir</translation>
    </message>
    <message>
        <location filename="../reader/uiframe/CentralDocPage.cpp" line="210"/>
        <source>Please check if the file is damaged</source>
        <translation>Verificar se o ficheiro está danificado</translation>
    </message>
    <message>
        <location filename="../reader/uiframe/CentralDocPage.cpp" line="212"/>
        <source>Conversion failed, please check if the file is damaged</source>
        <translation>Falha ao converter, verifique se o ficheiro está danificado</translation>
    </message>
    <message>
        <location filename="../reader/uiframe/CentralDocPage.cpp" line="420"/>
        <source>Save failed</source>
        <translation>Falha ao guardar</translation>
    </message>
    <message>
        <location filename="../reader/uiframe/CentralDocPage.cpp" line="426"/>
        <source>Saved successfully</source>
        <translation>Guardado com sucesso</translation>
    </message>
    <message>
        <location filename="../reader/uiframe/CentralDocPage.cpp" line="444"/>
        <source>Save as</source>
        <translation>Guardar como</translation>
    </message>
    <message>
        <location filename="../reader/uiframe/CentralDocPage.cpp" line="453"/>
        <location filename="../reader/uiframe/CentralDocPage.cpp" line="463"/>
        <source>Invalid file name</source>
        <translation>Nome de ficheiro inválido</translation>
    </message>
    <message>
        <location filename="../reader/uiframe/CentralDocPage.cpp" line="455"/>
        <location filename="../reader/uiframe/CentralDocPage.cpp" line="465"/>
        <source>OK</source>
        <comment>button</comment>
        <translation>Aceitar</translation>
    </message>
</context>
<context>
    <name>CentralNavPage</name>
    <message>
        <location filename="../reader/uiframe/CentralNavPage.cpp" line="35"/>
        <source>Drag documents here</source>
        <translation>Arraste documentos para aqui</translation>
    </message>
    <message>
        <location filename="../reader/uiframe/CentralNavPage.cpp" line="41"/>
        <source>Format supported: %1</source>
        <translation>Formato suportado: %1</translation>
    </message>
    <message>
        <location filename="../reader/uiframe/CentralNavPage.cpp" line="47"/>
        <source>Select File</source>
        <translation>Selecionar ficheiro</translation>
    </message>
</context>
<context>
    <name>DocSheet</name>
    <message>
        <location filename="../reader/uiframe/DocSheet.cpp" line="332"/>
        <location filename="../reader/uiframe/DocSheet.cpp" line="360"/>
        <source>The bookmark has been removed</source>
        <translation>O marcador foi removido</translation>
    </message>
    <message>
        <location filename="../reader/uiframe/DocSheet.cpp" line="533"/>
        <location filename="../reader/uiframe/DocSheet.cpp" line="548"/>
        <source>Please select the text</source>
        <translation>Selecione o texto</translation>
    </message>
    <message>
        <location filename="../reader/uiframe/DocSheet.cpp" line="598"/>
        <location filename="../reader/uiframe/DocSheet.cpp" line="607"/>
        <source>The annotation has been removed</source>
        <translation>A anotação foi removida</translation>
    </message>
</context>
<context>
    <name>EncryptionPage</name>
    <message>
        <location filename="../reader/widgets/EncryptionPage.cpp" line="50"/>
        <source>Encrypted file, please enter the password</source>
        <translation>Ficheiro encriptado, introduza a palavra-passe</translation>
    </message>
    <message>
        <location filename="../reader/widgets/EncryptionPage.cpp" line="56"/>
        <source>Password</source>
        <translation>Palavra-passe</translation>
    </message>
    <message>
        <location filename="../reader/widgets/EncryptionPage.cpp" line="61"/>
        <source>OK</source>
        <comment>button</comment>
        <translation>Aceitar</translation>
    </message>
    <message>
        <location filename="../reader/widgets/EncryptionPage.cpp" line="105"/>
        <source>Wrong password</source>
        <translation>Palavra-passe incorreta</translation>
    </message>
</context>
<context>
    <name>FindWidget</name>
    <message>
        <location filename="../reader/widgets/FindWidget.cpp" line="127"/>
        <source>Previous</source>
        <translation>Anterior</translation>
    </message>
    <message>
        <location filename="../reader/widgets/FindWidget.cpp" line="135"/>
        <source>Next</source>
        <translation>Seguinte</translation>
    </message>
</context>
<context>
    <name>HandleMenu</name>
    <message>
        <location filename="../reader/widgets/HandleMenu.cpp" line="35"/>
        <source>Select Text</source>
        <translation>Selecionar texto</translation>
    </message>
    <message>
        <location filename="../reader/widgets/HandleMenu.cpp" line="43"/>
        <source>Hand Tool</source>
        <translation>Ferramenta manual</translation>
    </message>
</context>
<context>
    <name>NotesWidget</name>
    <message>
        <location filename="../reader/sidebar/NotesWidget.cpp" line="67"/>
        <source>Add annotation</source>
        <translation>Adicionar anotação</translation>
    </message>
    <message>
        <location filename="../reader/sidebar/NotesWidget.cpp" line="189"/>
        <source>Are you sure you want to delete all annotations?</source>
        <translation>Tem a certeza que deseja eliminar todos as anotações?</translation>
    </message>
</context>
<context>
    <name>PagingWidget</name>
    <message>
        <location filename="../reader/widgets/PagingWidget.cpp" line="212"/>
        <source>Invalid page number</source>
        <translation>Número de página inválido</translation>
    </message>
</context>
<context>
    <name>ProgressDialog</name>
    <message>
        <location filename="../reader/widgets/ProgressDialog.cpp" line="18"/>
        <source>Converting</source>
        <translation>Convertendo</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../reader/app/DBusObject.cpp" line="103"/>
        <source>Document not saved</source>
        <translation>Documento não guardado</translation>
    </message>
</context>
<context>
    <name>SaveDialog</name>
    <message>
        <location filename="../reader/widgets/SaveDialog.cpp" line="35"/>
        <source>Save the changes to &quot;%1&quot;?</source>
        <translation>Guardar as alterações para &quot;%1&quot;?</translation>
    </message>
    <message>
        <location filename="../reader/widgets/SaveDialog.cpp" line="37"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../reader/widgets/SaveDialog.cpp" line="37"/>
        <source>Discard</source>
        <comment>button</comment>
        <translation>Descartar</translation>
    </message>
    <message>
        <location filename="../reader/widgets/SaveDialog.cpp" line="38"/>
        <source>Save</source>
        <comment>button</comment>
        <translation>Guardar</translation>
    </message>
    <message>
        <location filename="../reader/widgets/SaveDialog.cpp" line="49"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../reader/widgets/SaveDialog.cpp" line="50"/>
        <source>Delete</source>
        <translation>Eliminar</translation>
    </message>
</context>
<context>
    <name>ScaleMenu</name>
    <message>
        <location filename="../reader/widgets/ScaleMenu.cpp" line="35"/>
        <source>Two-Page View</source>
        <translation>Vista de duas páginas</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ScaleMenu.cpp" line="36"/>
        <source>1:1 size</source>
        <translation>Tamanho 1:1</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ScaleMenu.cpp" line="37"/>
        <source>Fit Page</source>
        <translation>Ajustar à página</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ScaleMenu.cpp" line="38"/>
        <source>Fit Height</source>
        <translation>Ajustar à altura</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ScaleMenu.cpp" line="39"/>
        <source>Fit Width</source>
        <translation>Ajustar à largura</translation>
    </message>
</context>
<context>
    <name>SearchResWidget</name>
    <message>
        <location filename="../reader/sidebar/SearchResWidget.cpp" line="60"/>
        <source>No search results</source>
        <translation>Sem resultados</translation>
    </message>
    <message>
        <location filename="../reader/sidebar/SearchResWidget.cpp" line="111"/>
        <source>%1 items found</source>
        <translation>%1 itens encontrados</translation>
    </message>
</context>
<context>
    <name>SecurityDialog</name>
    <message>
        <location filename="../reader/widgets/SecurityDialog.cpp" line="72"/>
        <source>This document is trying to connect to:</source>
        <translation>Este documento está a tentar ligar-se a:</translation>
    </message>
    <message>
        <location filename="../reader/widgets/SecurityDialog.cpp" line="73"/>
        <source>If you trust the website, click Allow, otherwise click Block.</source>
        <translation>Se confiar no website, clique em Permitir, caso contrário clique em Bloquear.</translation>
    </message>
    <message>
        <location filename="../reader/widgets/SecurityDialog.cpp" line="76"/>
        <source>Block</source>
        <comment>button</comment>
        <translation>Bloquear</translation>
    </message>
    <message>
        <location filename="../reader/widgets/SecurityDialog.cpp" line="77"/>
        <source>Allow</source>
        <comment>button</comment>
        <translation>Permitir</translation>
    </message>
</context>
<context>
    <name>SheetSidebar</name>
    <message>
        <location filename="../reader/sidebar/SheetSidebar.cpp" line="84"/>
        <source>Thumbnails</source>
        <translation>Miniaturas</translation>
    </message>
    <message>
        <location filename="../reader/sidebar/SheetSidebar.cpp" line="99"/>
        <source>Catalog</source>
        <translation>Catalogar</translation>
    </message>
    <message>
        <location filename="../reader/sidebar/SheetSidebar.cpp" line="112"/>
        <source>Bookmarks</source>
        <translation>Marcadores</translation>
    </message>
    <message>
        <location filename="../reader/sidebar/SheetSidebar.cpp" line="127"/>
        <source>Annotations</source>
        <translation>Anotações</translation>
    </message>
</context>
<context>
    <name>ShortCutShow</name>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="60"/>
        <source>Settings</source>
        <translation>Definições</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="124"/>
        <source>Exit</source>
        <translation>Sair</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="100"/>
        <source>Help</source>
        <translation>Ajuda</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="120"/>
        <source>Page up</source>
        <translation>Página acima</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="121"/>
        <source>Page down</source>
        <translation>Página abaixo</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="105"/>
        <source>Open</source>
        <translation>Abrir</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="118"/>
        <source>Zoom in</source>
        <translation>Ampliar</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="119"/>
        <source>Zoom out</source>
        <translation>Reduzir</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="106"/>
        <source>Save as</source>
        <translation>Guardar como</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="107"/>
        <source>Print</source>
        <translation>Imprimir</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="108"/>
        <source>Save</source>
        <translation>Guardar</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="112"/>
        <source>Thumbnails</source>
        <translation>Miniaturas</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="113"/>
        <source>1:1 size</source>
        <translation>Tamanho 1:1</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="114"/>
        <source>Fit height</source>
        <translation>Ajustar à altura</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="115"/>
        <source>Fit width</source>
        <translation>Ajustar à largura</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="116"/>
        <source>Rotate left</source>
        <translation>Rodar para a esquerda</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="117"/>
        <source>Rotate right</source>
        <translation>Rodar para a direita</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="122"/>
        <source>Move to the beginning</source>
        <translation>Mover para o início</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="123"/>
        <source>Move to the end</source>
        <translation>Mover para o fim</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="128"/>
        <source>Select text</source>
        <translation>Selecionar texto</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="129"/>
        <source>Hand tool</source>
        <translation>Ferramenta manual</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="130"/>
        <source>Add bookmark</source>
        <translation>Adicionar marcador</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="143"/>
        <source>Delete</source>
        <translation>Eliminar</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="133"/>
        <source>Magnifier</source>
        <translation>Lupa</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="135"/>
        <source>Slide show</source>
        <translation>Apresentação</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="136"/>
        <source>Fullscreen</source>
        <translation>Ecrã inteiro</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="140"/>
        <source>Copy</source>
        <translation>Copiar</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="141"/>
        <source>Cut</source>
        <translation>Cortar</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="142"/>
        <source>Paste</source>
        <translation>Colar</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="144"/>
        <source>Undo</source>
        <translation>Anular</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="145"/>
        <source>Select all</source>
        <translation>Selecionar tudo</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="101"/>
        <source>Display shortcuts</source>
        <translation>Mostrar atalhos</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="131"/>
        <source>Add annotation</source>
        <translation>Adicionar anotação</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="132"/>
        <source>Highlight</source>
        <translation>Destacar</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="134"/>
        <source>Search</source>
        <translation>Pesquisar</translation>
    </message>
</context>
<context>
    <name>SideBarImageListView</name>
    <message>
        <location filename="../reader/sidebar/SideBarImageListview.cpp" line="194"/>
        <source>Copy</source>
        <translation>Copiar</translation>
    </message>
    <message>
        <location filename="../reader/sidebar/SideBarImageListview.cpp" line="199"/>
        <source>Remove annotation</source>
        <translation>Remover anotação</translation>
    </message>
    <message>
        <location filename="../reader/sidebar/SideBarImageListview.cpp" line="204"/>
        <location filename="../reader/sidebar/SideBarImageListview.cpp" line="223"/>
        <source>Remove all</source>
        <translation>Remover tudo</translation>
    </message>
    <message>
        <location filename="../reader/sidebar/SideBarImageListview.cpp" line="218"/>
        <source>Remove bookmark</source>
        <translation>Remover marcador</translation>
    </message>
</context>
<context>
    <name>SideBarImageViewModel</name>
    <message>
        <location filename="../reader/sidebar/SideBarImageViewModel.cpp" line="135"/>
        <source>Page %1</source>
        <translation>Página %1</translation>
    </message>
</context>
<context>
    <name>SlidePlayWidget</name>
    <message>
        <location filename="../reader/widgets/SlidePlayWidget.cpp" line="127"/>
        <source>It is the first page</source>
        <translation>É a primeira página</translation>
    </message>
    <message>
        <location filename="../reader/widgets/SlidePlayWidget.cpp" line="132"/>
        <source>It is the last page</source>
        <translation>É a última página</translation>
    </message>
</context>
<context>
    <name>TitleMenu</name>
    <message>
        <location filename="../reader/uiframe/TitleMenu.cpp" line="29"/>
        <source>New window</source>
        <translation>Nova janela</translation>
    </message>
    <message>
        <location filename="../reader/uiframe/TitleMenu.cpp" line="29"/>
        <source>New tab</source>
        <translation>Novo separador</translation>
    </message>
    <message>
        <location filename="../reader/uiframe/TitleMenu.cpp" line="39"/>
        <location filename="../reader/uiframe/TitleMenu.cpp" line="110"/>
        <source>Save</source>
        <translation>Guardar</translation>
    </message>
    <message>
        <location filename="../reader/uiframe/TitleMenu.cpp" line="39"/>
        <source>Save as</source>
        <translation>Guardar como</translation>
    </message>
    <message>
        <location filename="../reader/uiframe/TitleMenu.cpp" line="44"/>
        <source>Display in file manager</source>
        <translation>Mostrar no gestor de ficheiros</translation>
    </message>
    <message>
        <location filename="../reader/uiframe/TitleMenu.cpp" line="44"/>
        <source>Magnifer</source>
        <translation>Lupa</translation>
    </message>
    <message>
        <location filename="../reader/uiframe/TitleMenu.cpp" line="50"/>
        <source>Tools</source>
        <translation>Ferramentas</translation>
    </message>
    <message>
        <location filename="../reader/uiframe/TitleMenu.cpp" line="54"/>
        <source>Search</source>
        <translation>Pesquisar</translation>
    </message>
    <message>
        <location filename="../reader/uiframe/TitleMenu.cpp" line="54"/>
        <source>Print</source>
        <translation>Imprimir</translation>
    </message>
</context>
<context>
    <name>TitleWidget</name>
    <message>
        <location filename="../reader/uiframe/TitleWidget.cpp" line="37"/>
        <source>Thumbnails</source>
        <translation>Miniaturas</translation>
    </message>
</context>
<context>
    <name>TransparentTextEdit</name>
    <message>
        <location filename="../reader/widgets/TransparentTextEdit.cpp" line="82"/>
        <source>Input limit reached</source>
        <translation>Atingiu o limite de caracteres</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../reader/main.cpp" line="40"/>
        <source>Document File Path.</source>
        <translation>Document File Path.</translation>
    </message>
    <message>
        <location filename="../reader/main.cpp" line="41"/>
        <location filename="../reader/main.cpp" line="45"/>
        <source>FilePath</source>
        <translation>FilePath</translation>
    </message>
    <message>
        <location filename="../reader/main.cpp" line="44"/>
        <source>ThumbnailPath Path.</source>
        <translation>ThumbnailPath Path.</translation>
    </message>
    <message>
        <location filename="../reader/main.cpp" line="49"/>
        <source>Generate thumbnail.</source>
        <translation>Generate thumbnail.</translation>
    </message>
</context>
</TS>